@@ -1,8 +1,8 @@
 use crate::{
     blockstore::Blockstore,
     blockstore_processor::{
-        self, BlockstoreProcessorError, BlockstoreProcessorResult, ProcessOptions,
-        TransactionStatusSender,
+        self, BlockstoreProcessorError, BlockstoreProcessorResult, CacheBlockTimeSender,
+        ProcessOptions, TransactionStatusSender,
     },
     entry::VerifyRecyclers,
     leader_schedule_cache::LeaderScheduleCache,
@@ -36,7 +36,8 @@ pub fn load(
     shrink_paths: Option<Vec<PathBuf>>,
     snapshot_config: Option<&SnapshotConfig>,
     process_options: ProcessOptions,
-    transaction_status_sender: Option<TransactionStatusSender>,
+    transaction_status_sender: Option<&TransactionStatusSender>,
+    cache_block_time_sender: Option<&CacheBlockTimeSender>,
 ) -> LoadResult {
     if let Some(snapshot_config) = snapshot_config.as_ref() {
         info!(
@@ -96,6 +97,7 @@ pub fn load(
                         &process_options,
                         &VerifyRecyclers::default(),
                         transaction_status_sender,
+                        cache_block_time_sender,
                     ),
                     Some(deserialized_snapshot_hash),
                 );
@@ -113,6 +115,7 @@ pub fn load(
             &blockstore,
             account_paths,
             process_options,
+            cache_block_time_sender,
         ),
         None,
     )
